==> tgam-patterns-2.1.52.tgz: package/patterns/javascripts/text-resizer.js <==
/**
 * dispatches an event when the text size has changed and shows an example of what the text would look like
 */

import ee from "./event-emitter";
import { toArray } from "./dom-methods";

let fontSizeIndex = 0;
let previousIndex = null;

/**
 * @method init
 * @description TODO
 * @param rootElement {HTMLElement}
 * @return {void}
 */
function init(rootElement) {
  let textResizers = toArray(rootElement.querySelectorAll(".c-control__button--text-sizer"));

  textResizers.forEach((el, index) => {
    el.addEventListener("click", this.onTextResizeClicked.bind(this, index));
  });

  ee.on("text-resizer:text-size-changed", onTextChanged);
}

/**
 * @method onTextResizeClicked
 * @description TODO
 * @param index {number}
 * @return {void}
 */
function onTextResizeClicked(index) {
  fontSizeIndex = index;

  ee.emit("text-resizer:text-size-changed", fontSizeIndex);
}

/**
 * @method onTextChanged
 * @description TODO
 * @param buttonIndex {number}
 * @return {void}
 */
function onTextChanged(buttonIndex) {
  const modifierClasses = ["", "c-text-sizer__body-text--plus-2", "c-text-sizer__body-text--plus-4", "c-text-sizer__body-text--plus-6"];
  const articleBody = document.querySelector(".c-text-sizer__body-text");

  previousIndex && articleBody.classList.remove(modifierClasses[previousIndex]);
  modifierClasses[buttonIndex] && articleBody.classList.add(modifierClasses[buttonIndex]);
  previousIndex = buttonIndex;
}

/////////////////////////////////////////
/////////////////////////////////////////
/////////////////////////////////////////

const textResizerObj = {};

textResizerObj.init = init;

textResizerObj.onTextResizeClicked = onTextResizeClicked;

textResizerObj.onTextChanged = onTextChanged;

export default textResizerObj;

==> tgam-patterns-2.1.65.tgz: package/patterns/javascripts/text-resizer.js <==
/**
 * dispatches an event when the text size has changed and shows an example of what the text would look like
 */

import ee from "./event-emitter";
import { toArray } from "./dom-methods";

let fontSizeIndex = 0;
let previousIndex = null;

/**
 * @method init
 * @description TODO
 * @param rootElement {HTMLElement}
 * @return {void}
 */
function init(rootElement) {
  let textResizers = toArray(rootElement.querySelectorAll(".c-control__button--text-resizer"));

  textResizers.forEach((el, index) => {
    el.addEventListener("click", this.onTextResizeClicked.bind(this, index));
  });

  ee.on("text-resizer:text-size-changed", onTextChanged);
}

/**
 * @method onTextResizeClicked
 * @description TODO
 * @param index {number}
 * @return {void}
 */
function onTextResizeClicked(index) {
  fontSizeIndex = index;

  ee.emit("text-resizer:text-size-changed", fontSizeIndex);
}

/**
 * @method onTextChanged
 * @description TODO
 * @param buttonIndex {number}
 * @return {void}
 */
function onTextChanged(buttonIndex) {
  const modifierClasses = ["", "c-text-resizer__body-text--plus-2", "c-text-resizer__body-text--plus-4", "c-text-resizer__body-text--plus-6"];
  const articleBody = document.querySelector(".c-text-resizer__body-text");

  previousIndex && articleBody.classList.remove(modifierClasses[previousIndex]);
  modifierClasses[buttonIndex] && articleBody.classList.add(modifierClasses[buttonIndex]);
  previousIndex = buttonIndex;
}

/////////////////////////////////////////
/////////////////////////////////////////
/////////////////////////////////////////

const textResizerObj = {};

textResizerObj.init = init;

textResizerObj.onTextResizeClicked = onTextResizeClicked;

textResizerObj.onTextChanged = onTextChanged;

export default textResizerObj;
